# coding: utf-8

# flake8: noqa

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

__version__ = "0.10.5.20201210.184141a1"

# import apis into sdk package
from symbol_openapi_client.api.account_routes_api import AccountRoutesApi
from symbol_openapi_client.api.block_routes_api import BlockRoutesApi
from symbol_openapi_client.api.chain_routes_api import ChainRoutesApi
from symbol_openapi_client.api.finalization_routes_api import FinalizationRoutesApi
from symbol_openapi_client.api.hash_lock_routes_api import HashLockRoutesApi
from symbol_openapi_client.api.metadata_routes_api import MetadataRoutesApi
from symbol_openapi_client.api.mosaic_routes_api import MosaicRoutesApi
from symbol_openapi_client.api.multisig_routes_api import MultisigRoutesApi
from symbol_openapi_client.api.namespace_routes_api import NamespaceRoutesApi
from symbol_openapi_client.api.network_routes_api import NetworkRoutesApi
from symbol_openapi_client.api.node_routes_api import NodeRoutesApi
from symbol_openapi_client.api.receipt_routes_api import ReceiptRoutesApi
from symbol_openapi_client.api.restriction_account_routes_api import RestrictionAccountRoutesApi
from symbol_openapi_client.api.restriction_mosaic_routes_api import RestrictionMosaicRoutesApi
from symbol_openapi_client.api.secret_lock_routes_api import SecretLockRoutesApi
from symbol_openapi_client.api.transaction_routes_api import TransactionRoutesApi
from symbol_openapi_client.api.transaction_status_routes_api import TransactionStatusRoutesApi

# import ApiClient
from symbol_openapi_client.api_client import ApiClient
from symbol_openapi_client.configuration import Configuration
from symbol_openapi_client.exceptions import OpenApiException
from symbol_openapi_client.exceptions import ApiTypeError
from symbol_openapi_client.exceptions import ApiValueError
from symbol_openapi_client.exceptions import ApiKeyError
from symbol_openapi_client.exceptions import ApiException
# import models into sdk package
from symbol_openapi_client.models.account_address_restriction_transaction_body_dto import AccountAddressRestrictionTransactionBodyDTO
from symbol_openapi_client.models.account_address_restriction_transaction_dto import AccountAddressRestrictionTransactionDTO
from symbol_openapi_client.models.account_dto import AccountDTO
from symbol_openapi_client.models.account_ids import AccountIds
from symbol_openapi_client.models.account_info_dto import AccountInfoDTO
from symbol_openapi_client.models.account_key_link_network_properties_dto import AccountKeyLinkNetworkPropertiesDTO
from symbol_openapi_client.models.account_key_link_transaction_body_dto import AccountKeyLinkTransactionBodyDTO
from symbol_openapi_client.models.account_key_link_transaction_dto import AccountKeyLinkTransactionDTO
from symbol_openapi_client.models.account_key_type_flags_enum import AccountKeyTypeFlagsEnum
from symbol_openapi_client.models.account_link_public_key_dto import AccountLinkPublicKeyDTO
from symbol_openapi_client.models.account_link_voting_key_dto import AccountLinkVotingKeyDTO
from symbol_openapi_client.models.account_link_voting_keys_dto import AccountLinkVotingKeysDTO
from symbol_openapi_client.models.account_metadata_transaction_body_dto import AccountMetadataTransactionBodyDTO
from symbol_openapi_client.models.account_metadata_transaction_dto import AccountMetadataTransactionDTO
from symbol_openapi_client.models.account_mosaic_restriction_transaction_body_dto import AccountMosaicRestrictionTransactionBodyDTO
from symbol_openapi_client.models.account_mosaic_restriction_transaction_dto import AccountMosaicRestrictionTransactionDTO
from symbol_openapi_client.models.account_names_dto import AccountNamesDTO
from symbol_openapi_client.models.account_operation_restriction_transaction_body_dto import AccountOperationRestrictionTransactionBodyDTO
from symbol_openapi_client.models.account_operation_restriction_transaction_dto import AccountOperationRestrictionTransactionDTO
from symbol_openapi_client.models.account_order_by_enum import AccountOrderByEnum
from symbol_openapi_client.models.account_page import AccountPage
from symbol_openapi_client.models.account_restriction_dto import AccountRestrictionDTO
from symbol_openapi_client.models.account_restriction_flags_enum import AccountRestrictionFlagsEnum
from symbol_openapi_client.models.account_restriction_network_properties_dto import AccountRestrictionNetworkPropertiesDTO
from symbol_openapi_client.models.account_restrictions_dto import AccountRestrictionsDTO
from symbol_openapi_client.models.account_restrictions_info_dto import AccountRestrictionsInfoDTO
from symbol_openapi_client.models.account_restrictions_page import AccountRestrictionsPage
from symbol_openapi_client.models.account_type_enum import AccountTypeEnum
from symbol_openapi_client.models.accounts_names_dto import AccountsNamesDTO
from symbol_openapi_client.models.activity_bucket_dto import ActivityBucketDTO
from symbol_openapi_client.models.address_alias_transaction_body_dto import AddressAliasTransactionBodyDTO
from symbol_openapi_client.models.address_alias_transaction_dto import AddressAliasTransactionDTO
from symbol_openapi_client.models.addresses import Addresses
from symbol_openapi_client.models.aggregate_network_properties_dto import AggregateNetworkPropertiesDTO
from symbol_openapi_client.models.aggregate_transaction_body_dto import AggregateTransactionBodyDTO
from symbol_openapi_client.models.aggregate_transaction_body_extended_dto import AggregateTransactionBodyExtendedDTO
from symbol_openapi_client.models.aggregate_transaction_dto import AggregateTransactionDTO
from symbol_openapi_client.models.aggregate_transaction_extended_dto import AggregateTransactionExtendedDTO
from symbol_openapi_client.models.alias_action_enum import AliasActionEnum
from symbol_openapi_client.models.alias_dto import AliasDTO
from symbol_openapi_client.models.alias_type_enum import AliasTypeEnum
from symbol_openapi_client.models.announce_transaction_info_dto import AnnounceTransactionInfoDTO
from symbol_openapi_client.models.balance_change_receipt_dto import BalanceChangeReceiptDTO
from symbol_openapi_client.models.balance_change_receipt_dto_all_of import BalanceChangeReceiptDTOAllOf
from symbol_openapi_client.models.balance_transfer_receipt_dto import BalanceTransferReceiptDTO
from symbol_openapi_client.models.balance_transfer_receipt_dto_all_of import BalanceTransferReceiptDTOAllOf
from symbol_openapi_client.models.block_dto import BlockDTO
from symbol_openapi_client.models.block_dto_all_of import BlockDTOAllOf
from symbol_openapi_client.models.block_info_dto import BlockInfoDTO
from symbol_openapi_client.models.block_meta_dto import BlockMetaDTO
from symbol_openapi_client.models.block_order_by_enum import BlockOrderByEnum
from symbol_openapi_client.models.block_page import BlockPage
from symbol_openapi_client.models.bm_tree_signature import BmTreeSignature
from symbol_openapi_client.models.chain_info_dto import ChainInfoDTO
from symbol_openapi_client.models.chain_properties_dto import ChainPropertiesDTO
from symbol_openapi_client.models.communication_timestamps_dto import CommunicationTimestampsDTO
from symbol_openapi_client.models.cosignature import Cosignature
from symbol_openapi_client.models.cosignature_dto import CosignatureDTO
from symbol_openapi_client.models.cosignature_dto_all_of import CosignatureDTOAllOf
from symbol_openapi_client.models.embedded_account_address_restriction_transaction_dto import EmbeddedAccountAddressRestrictionTransactionDTO
from symbol_openapi_client.models.embedded_account_key_link_transaction_dto import EmbeddedAccountKeyLinkTransactionDTO
from symbol_openapi_client.models.embedded_account_metadata_transaction_dto import EmbeddedAccountMetadataTransactionDTO
from symbol_openapi_client.models.embedded_account_mosaic_restriction_transaction_dto import EmbeddedAccountMosaicRestrictionTransactionDTO
from symbol_openapi_client.models.embedded_account_operation_restriction_transaction_dto import EmbeddedAccountOperationRestrictionTransactionDTO
from symbol_openapi_client.models.embedded_address_alias_transaction_dto import EmbeddedAddressAliasTransactionDTO
from symbol_openapi_client.models.embedded_hash_lock_transaction_dto import EmbeddedHashLockTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_address_restriction_transaction_dto import EmbeddedMosaicAddressRestrictionTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_alias_transaction_dto import EmbeddedMosaicAliasTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_definition_transaction_dto import EmbeddedMosaicDefinitionTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_global_restriction_transaction_dto import EmbeddedMosaicGlobalRestrictionTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_metadata_transaction_dto import EmbeddedMosaicMetadataTransactionDTO
from symbol_openapi_client.models.embedded_mosaic_supply_change_transaction_dto import EmbeddedMosaicSupplyChangeTransactionDTO
from symbol_openapi_client.models.embedded_multisig_account_modification_transaction_dto import EmbeddedMultisigAccountModificationTransactionDTO
from symbol_openapi_client.models.embedded_namespace_metadata_transaction_dto import EmbeddedNamespaceMetadataTransactionDTO
from symbol_openapi_client.models.embedded_namespace_registration_transaction_dto import EmbeddedNamespaceRegistrationTransactionDTO
from symbol_openapi_client.models.embedded_node_key_link_transaction_dto import EmbeddedNodeKeyLinkTransactionDTO
from symbol_openapi_client.models.embedded_secret_lock_transaction_dto import EmbeddedSecretLockTransactionDTO
from symbol_openapi_client.models.embedded_secret_proof_transaction_dto import EmbeddedSecretProofTransactionDTO
from symbol_openapi_client.models.embedded_transaction_body_dto import EmbeddedTransactionBodyDTO
from symbol_openapi_client.models.embedded_transaction_dto import EmbeddedTransactionDTO
from symbol_openapi_client.models.embedded_transaction_info_dto import EmbeddedTransactionInfoDTO
from symbol_openapi_client.models.embedded_transaction_meta_dto import EmbeddedTransactionMetaDTO
from symbol_openapi_client.models.embedded_transfer_transaction_dto import EmbeddedTransferTransactionDTO
from symbol_openapi_client.models.embedded_voting_key_link_transaction_dto import EmbeddedVotingKeyLinkTransactionDTO
from symbol_openapi_client.models.embedded_vrf_key_link_transaction_dto import EmbeddedVrfKeyLinkTransactionDTO
from symbol_openapi_client.models.entity_dto import EntityDTO
from symbol_openapi_client.models.finalization_proof_dto import FinalizationProofDTO
from symbol_openapi_client.models.finalized_block_dto import FinalizedBlockDTO
from symbol_openapi_client.models.hash_lock_entry_dto import HashLockEntryDTO
from symbol_openapi_client.models.hash_lock_info_dto import HashLockInfoDTO
from symbol_openapi_client.models.hash_lock_network_properties_dto import HashLockNetworkPropertiesDTO
from symbol_openapi_client.models.hash_lock_page import HashLockPage
from symbol_openapi_client.models.hash_lock_transaction_body_dto import HashLockTransactionBodyDTO
from symbol_openapi_client.models.hash_lock_transaction_dto import HashLockTransactionDTO
from symbol_openapi_client.models.importance_block_dto import ImportanceBlockDTO
from symbol_openapi_client.models.importance_block_dto_all_of import ImportanceBlockDTOAllOf
from symbol_openapi_client.models.inflation_receipt_dto import InflationReceiptDTO
from symbol_openapi_client.models.inflation_receipt_dto_all_of import InflationReceiptDTOAllOf
from symbol_openapi_client.models.link_action_enum import LinkActionEnum
from symbol_openapi_client.models.lock_hash_algorithm_enum import LockHashAlgorithmEnum
from symbol_openapi_client.models.lock_status import LockStatus
from symbol_openapi_client.models.merkle_path_item_dto import MerklePathItemDTO
from symbol_openapi_client.models.merkle_proof_info_dto import MerkleProofInfoDTO
from symbol_openapi_client.models.merkle_state_info_dto import MerkleStateInfoDTO
from symbol_openapi_client.models.merkle_tree_branch_dto import MerkleTreeBranchDTO
from symbol_openapi_client.models.merkle_tree_branch_link_dto import MerkleTreeBranchLinkDTO
from symbol_openapi_client.models.merkle_tree_leaf_dto import MerkleTreeLeafDTO
from symbol_openapi_client.models.merkle_tree_node_type_enum import MerkleTreeNodeTypeEnum
from symbol_openapi_client.models.message_group import MessageGroup
from symbol_openapi_client.models.metadata_entry_dto import MetadataEntryDTO
from symbol_openapi_client.models.metadata_info_dto import MetadataInfoDTO
from symbol_openapi_client.models.metadata_network_properties_dto import MetadataNetworkPropertiesDTO
from symbol_openapi_client.models.metadata_page import MetadataPage
from symbol_openapi_client.models.metadata_type_enum import MetadataTypeEnum
from symbol_openapi_client.models.model_error import ModelError
from symbol_openapi_client.models.mosaic import Mosaic
from symbol_openapi_client.models.mosaic_address_restriction_dto import MosaicAddressRestrictionDTO
from symbol_openapi_client.models.mosaic_address_restriction_entry_dto import MosaicAddressRestrictionEntryDTO
from symbol_openapi_client.models.mosaic_address_restriction_entry_wrapper_dto import MosaicAddressRestrictionEntryWrapperDTO
from symbol_openapi_client.models.mosaic_address_restriction_transaction_body_dto import MosaicAddressRestrictionTransactionBodyDTO
from symbol_openapi_client.models.mosaic_address_restriction_transaction_dto import MosaicAddressRestrictionTransactionDTO
from symbol_openapi_client.models.mosaic_alias_transaction_body_dto import MosaicAliasTransactionBodyDTO
from symbol_openapi_client.models.mosaic_alias_transaction_dto import MosaicAliasTransactionDTO
from symbol_openapi_client.models.mosaic_dto import MosaicDTO
from symbol_openapi_client.models.mosaic_definition_transaction_body_dto import MosaicDefinitionTransactionBodyDTO
from symbol_openapi_client.models.mosaic_definition_transaction_dto import MosaicDefinitionTransactionDTO
from symbol_openapi_client.models.mosaic_expiry_receipt_dto import MosaicExpiryReceiptDTO
from symbol_openapi_client.models.mosaic_expiry_receipt_dto_all_of import MosaicExpiryReceiptDTOAllOf
from symbol_openapi_client.models.mosaic_global_restriction_dto import MosaicGlobalRestrictionDTO
from symbol_openapi_client.models.mosaic_global_restriction_entry_dto import MosaicGlobalRestrictionEntryDTO
from symbol_openapi_client.models.mosaic_global_restriction_entry_restriction_dto import MosaicGlobalRestrictionEntryRestrictionDTO
from symbol_openapi_client.models.mosaic_global_restriction_entry_wrapper_dto import MosaicGlobalRestrictionEntryWrapperDTO
from symbol_openapi_client.models.mosaic_global_restriction_transaction_body_dto import MosaicGlobalRestrictionTransactionBodyDTO
from symbol_openapi_client.models.mosaic_global_restriction_transaction_dto import MosaicGlobalRestrictionTransactionDTO
from symbol_openapi_client.models.mosaic_ids import MosaicIds
from symbol_openapi_client.models.mosaic_info_dto import MosaicInfoDTO
from symbol_openapi_client.models.mosaic_metadata_transaction_body_dto import MosaicMetadataTransactionBodyDTO
from symbol_openapi_client.models.mosaic_metadata_transaction_dto import MosaicMetadataTransactionDTO
from symbol_openapi_client.models.mosaic_names_dto import MosaicNamesDTO
from symbol_openapi_client.models.mosaic_network_properties_dto import MosaicNetworkPropertiesDTO
from symbol_openapi_client.models.mosaic_page import MosaicPage
from symbol_openapi_client.models.mosaic_restriction_dto import MosaicRestrictionDTO
from symbol_openapi_client.models.mosaic_restriction_entry_type_enum import MosaicRestrictionEntryTypeEnum
from symbol_openapi_client.models.mosaic_restriction_network_properties_dto import MosaicRestrictionNetworkPropertiesDTO
from symbol_openapi_client.models.mosaic_restriction_type_enum import MosaicRestrictionTypeEnum
from symbol_openapi_client.models.mosaic_restrictions_page import MosaicRestrictionsPage
from symbol_openapi_client.models.mosaic_supply_change_action_enum import MosaicSupplyChangeActionEnum
from symbol_openapi_client.models.mosaic_supply_change_transaction_body_dto import MosaicSupplyChangeTransactionBodyDTO
from symbol_openapi_client.models.mosaic_supply_change_transaction_dto import MosaicSupplyChangeTransactionDTO
from symbol_openapi_client.models.mosaics_names_dto import MosaicsNamesDTO
from symbol_openapi_client.models.multisig_account_graph_info_dto import MultisigAccountGraphInfoDTO
from symbol_openapi_client.models.multisig_account_info_dto import MultisigAccountInfoDTO
from symbol_openapi_client.models.multisig_account_modification_transaction_body_dto import MultisigAccountModificationTransactionBodyDTO
from symbol_openapi_client.models.multisig_account_modification_transaction_dto import MultisigAccountModificationTransactionDTO
from symbol_openapi_client.models.multisig_dto import MultisigDTO
from symbol_openapi_client.models.multisig_network_properties_dto import MultisigNetworkPropertiesDTO
from symbol_openapi_client.models.namespace_dto import NamespaceDTO
from symbol_openapi_client.models.namespace_expiry_receipt_dto import NamespaceExpiryReceiptDTO
from symbol_openapi_client.models.namespace_expiry_receipt_dto_all_of import NamespaceExpiryReceiptDTOAllOf
from symbol_openapi_client.models.namespace_ids import NamespaceIds
from symbol_openapi_client.models.namespace_info_dto import NamespaceInfoDTO
from symbol_openapi_client.models.namespace_meta_dto import NamespaceMetaDTO
from symbol_openapi_client.models.namespace_metadata_transaction_body_dto import NamespaceMetadataTransactionBodyDTO
from symbol_openapi_client.models.namespace_metadata_transaction_dto import NamespaceMetadataTransactionDTO
from symbol_openapi_client.models.namespace_name_dto import NamespaceNameDTO
from symbol_openapi_client.models.namespace_network_properties_dto import NamespaceNetworkPropertiesDTO
from symbol_openapi_client.models.namespace_page import NamespacePage
from symbol_openapi_client.models.namespace_registration_transaction_body_dto import NamespaceRegistrationTransactionBodyDTO
from symbol_openapi_client.models.namespace_registration_transaction_dto import NamespaceRegistrationTransactionDTO
from symbol_openapi_client.models.namespace_registration_type_enum import NamespaceRegistrationTypeEnum
from symbol_openapi_client.models.network_configuration_dto import NetworkConfigurationDTO
from symbol_openapi_client.models.network_properties_dto import NetworkPropertiesDTO
from symbol_openapi_client.models.network_type_dto import NetworkTypeDTO
from symbol_openapi_client.models.network_type_enum import NetworkTypeEnum
from symbol_openapi_client.models.node_health_dto import NodeHealthDTO
from symbol_openapi_client.models.node_health_info_dto import NodeHealthInfoDTO
from symbol_openapi_client.models.node_identity_equality_strategy import NodeIdentityEqualityStrategy
from symbol_openapi_client.models.node_info_dto import NodeInfoDTO
from symbol_openapi_client.models.node_key_link_network_properties_dto import NodeKeyLinkNetworkPropertiesDTO
from symbol_openapi_client.models.node_key_link_transaction_body_dto import NodeKeyLinkTransactionBodyDTO
from symbol_openapi_client.models.node_key_link_transaction_dto import NodeKeyLinkTransactionDTO
from symbol_openapi_client.models.node_status_enum import NodeStatusEnum
from symbol_openapi_client.models.node_time_dto import NodeTimeDTO
from symbol_openapi_client.models.order import Order
from symbol_openapi_client.models.pagination import Pagination
from symbol_openapi_client.models.parent_public_key_signature_pair import ParentPublicKeySignaturePair
from symbol_openapi_client.models.plugins_properties_dto import PluginsPropertiesDTO
from symbol_openapi_client.models.position_enum import PositionEnum
from symbol_openapi_client.models.receipt_dto import ReceiptDTO
from symbol_openapi_client.models.receipt_type_enum import ReceiptTypeEnum
from symbol_openapi_client.models.rental_fees_dto import RentalFeesDTO
from symbol_openapi_client.models.resolution_entry_dto import ResolutionEntryDTO
from symbol_openapi_client.models.resolution_statement_dto import ResolutionStatementDTO
from symbol_openapi_client.models.resolution_statement_info_dto import ResolutionStatementInfoDTO
from symbol_openapi_client.models.resolution_statement_page import ResolutionStatementPage
from symbol_openapi_client.models.secret_lock_entry_dto import SecretLockEntryDTO
from symbol_openapi_client.models.secret_lock_info_dto import SecretLockInfoDTO
from symbol_openapi_client.models.secret_lock_network_properties_dto import SecretLockNetworkPropertiesDTO
from symbol_openapi_client.models.secret_lock_page import SecretLockPage
from symbol_openapi_client.models.secret_lock_transaction_body_dto import SecretLockTransactionBodyDTO
from symbol_openapi_client.models.secret_lock_transaction_dto import SecretLockTransactionDTO
from symbol_openapi_client.models.secret_proof_transaction_body_dto import SecretProofTransactionBodyDTO
from symbol_openapi_client.models.secret_proof_transaction_dto import SecretProofTransactionDTO
from symbol_openapi_client.models.server_dto import ServerDTO
from symbol_openapi_client.models.server_info_dto import ServerInfoDTO
from symbol_openapi_client.models.size_prefixed_entity_dto import SizePrefixedEntityDTO
from symbol_openapi_client.models.source_dto import SourceDTO
from symbol_openapi_client.models.stage_enum import StageEnum
from symbol_openapi_client.models.storage_info_dto import StorageInfoDTO
from symbol_openapi_client.models.supplemental_public_keys_dto import SupplementalPublicKeysDTO
from symbol_openapi_client.models.transaction_body_dto import TransactionBodyDTO
from symbol_openapi_client.models.transaction_dto import TransactionDTO
from symbol_openapi_client.models.transaction_fees_dto import TransactionFeesDTO
from symbol_openapi_client.models.transaction_group_enum import TransactionGroupEnum
from symbol_openapi_client.models.transaction_hashes import TransactionHashes
from symbol_openapi_client.models.transaction_ids import TransactionIds
from symbol_openapi_client.models.transaction_info_dto import TransactionInfoDTO
from symbol_openapi_client.models.transaction_meta_dto import TransactionMetaDTO
from symbol_openapi_client.models.transaction_page import TransactionPage
from symbol_openapi_client.models.transaction_payload import TransactionPayload
from symbol_openapi_client.models.transaction_statement_dto import TransactionStatementDTO
from symbol_openapi_client.models.transaction_statement_info_dto import TransactionStatementInfoDTO
from symbol_openapi_client.models.transaction_statement_page import TransactionStatementPage
from symbol_openapi_client.models.transaction_status_dto import TransactionStatusDTO
from symbol_openapi_client.models.transaction_status_enum import TransactionStatusEnum
from symbol_openapi_client.models.transaction_type_enum import TransactionTypeEnum
from symbol_openapi_client.models.transfer_network_properties_dto import TransferNetworkPropertiesDTO
from symbol_openapi_client.models.transfer_transaction_body_dto import TransferTransactionBodyDTO
from symbol_openapi_client.models.transfer_transaction_dto import TransferTransactionDTO
from symbol_openapi_client.models.unlocked_account_dto import UnlockedAccountDTO
from symbol_openapi_client.models.unresolved_mosaic import UnresolvedMosaic
from symbol_openapi_client.models.verifiable_entity_dto import VerifiableEntityDTO
from symbol_openapi_client.models.voting_key_link_network_properties_dto import VotingKeyLinkNetworkPropertiesDTO
from symbol_openapi_client.models.voting_key_link_transaction_body_dto import VotingKeyLinkTransactionBodyDTO
from symbol_openapi_client.models.voting_key_link_transaction_dto import VotingKeyLinkTransactionDTO
from symbol_openapi_client.models.vrf_key_link_network_properties_dto import VrfKeyLinkNetworkPropertiesDTO
from symbol_openapi_client.models.vrf_key_link_transaction_body_dto import VrfKeyLinkTransactionBodyDTO
from symbol_openapi_client.models.vrf_key_link_transaction_dto import VrfKeyLinkTransactionDTO




# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class MultisigDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'int',
        'account_address': 'str',
        'min_approval': 'int',
        'min_removal': 'int',
        'cosignatory_addresses': 'list[str]',
        'multisig_addresses': 'list[str]'
    }

    attribute_map = {
        'version': 'version',
        'account_address': 'accountAddress',
        'min_approval': 'minApproval',
        'min_removal': 'minRemoval',
        'cosignatory_addresses': 'cosignatoryAddresses',
        'multisig_addresses': 'multisigAddresses'
    }

    def __init__(self, version=None, account_address=None, min_approval=None, min_removal=None, cosignatory_addresses=None, multisig_addresses=None, local_vars_configuration=None):  # noqa: E501
        """MultisigDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._account_address = None
        self._min_approval = None
        self._min_removal = None
        self._cosignatory_addresses = None
        self._multisig_addresses = None
        self.discriminator = None

        self.version = version
        self.account_address = account_address
        self.min_approval = min_approval
        self.min_removal = min_removal
        self.cosignatory_addresses = cosignatory_addresses
        self.multisig_addresses = multisig_addresses

    @property
    def version(self):
        """Gets the version of this MultisigDTO.  # noqa: E501

        The version of the state  # noqa: E501

        :return: The version of this MultisigDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this MultisigDTO.

        The version of the state  # noqa: E501

        :param version: The version of this MultisigDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def account_address(self):
        """Gets the account_address of this MultisigDTO.  # noqa: E501

        Address expressed in hexadecimal base.  # noqa: E501

        :return: The account_address of this MultisigDTO.  # noqa: E501
        :rtype: str
        """
        return self._account_address

    @account_address.setter
    def account_address(self, account_address):
        """Sets the account_address of this MultisigDTO.

        Address expressed in hexadecimal base.  # noqa: E501

        :param account_address: The account_address of this MultisigDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_address is None:  # noqa: E501
            raise ValueError("Invalid value for `account_address`, must not be `None`")  # noqa: E501

        self._account_address = account_address

    @property
    def min_approval(self):
        """Gets the min_approval of this MultisigDTO.  # noqa: E501

        A number that allows uint 32 values.  # noqa: E501

        :return: The min_approval of this MultisigDTO.  # noqa: E501
        :rtype: int
        """
        return self._min_approval

    @min_approval.setter
    def min_approval(self, min_approval):
        """Sets the min_approval of this MultisigDTO.

        A number that allows uint 32 values.  # noqa: E501

        :param min_approval: The min_approval of this MultisigDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_approval is None:  # noqa: E501
            raise ValueError("Invalid value for `min_approval`, must not be `None`")  # noqa: E501

        self._min_approval = min_approval

    @property
    def min_removal(self):
        """Gets the min_removal of this MultisigDTO.  # noqa: E501

        A number that allows uint 32 values.  # noqa: E501

        :return: The min_removal of this MultisigDTO.  # noqa: E501
        :rtype: int
        """
        return self._min_removal

    @min_removal.setter
    def min_removal(self, min_removal):
        """Sets the min_removal of this MultisigDTO.

        A number that allows uint 32 values.  # noqa: E501

        :param min_removal: The min_removal of this MultisigDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and min_removal is None:  # noqa: E501
            raise ValueError("Invalid value for `min_removal`, must not be `None`")  # noqa: E501

        self._min_removal = min_removal

    @property
    def cosignatory_addresses(self):
        """Gets the cosignatory_addresses of this MultisigDTO.  # noqa: E501

        Addresses of the cosignatory accounts.  # noqa: E501

        :return: The cosignatory_addresses of this MultisigDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._cosignatory_addresses

    @cosignatory_addresses.setter
    def cosignatory_addresses(self, cosignatory_addresses):
        """Sets the cosignatory_addresses of this MultisigDTO.

        Addresses of the cosignatory accounts.  # noqa: E501

        :param cosignatory_addresses: The cosignatory_addresses of this MultisigDTO.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and cosignatory_addresses is None:  # noqa: E501
            raise ValueError("Invalid value for `cosignatory_addresses`, must not be `None`")  # noqa: E501

        self._cosignatory_addresses = cosignatory_addresses

    @property
    def multisig_addresses(self):
        """Gets the multisig_addresses of this MultisigDTO.  # noqa: E501

        Multisig accounts where the account is cosignatory.  # noqa: E501

        :return: The multisig_addresses of this MultisigDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._multisig_addresses

    @multisig_addresses.setter
    def multisig_addresses(self, multisig_addresses):
        """Sets the multisig_addresses of this MultisigDTO.

        Multisig accounts where the account is cosignatory.  # noqa: E501

        :param multisig_addresses: The multisig_addresses of this MultisigDTO.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and multisig_addresses is None:  # noqa: E501
            raise ValueError("Invalid value for `multisig_addresses`, must not be `None`")  # noqa: E501

        self._multisig_addresses = multisig_addresses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultisigDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MultisigDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from symbol_openapi_client.api_client import ApiClient
from symbol_openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ChainRoutesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_chain_info(self, **kwargs):  # noqa: E501
        """Get the current information of the chain  # noqa: E501

        Returns the current information of the blockchain.  The higher the score, the better the chain. During synchronization, nodes try to get the best blockchain in the network.  The score for a block is derived from its difficulty and the time (in seconds) that has elapsed since the last block:      block score = difficulty − time elapsed since last block   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ChainInfoDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_chain_info_with_http_info(**kwargs)  # noqa: E501

    def get_chain_info_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current information of the chain  # noqa: E501

        Returns the current information of the blockchain.  The higher the score, the better the chain. During synchronization, nodes try to get the best blockchain in the network.  The score for a block is derived from its difficulty and the time (in seconds) that has elapsed since the last block:      block score = difficulty − time elapsed since last block   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ChainInfoDTO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chain_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/chain/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChainInfoDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class BlockDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'size': 'int',
        'signature': 'str',
        'signer_public_key': 'str',
        'version': 'int',
        'network': 'NetworkTypeEnum',
        'type': 'int',
        'height': 'str',
        'timestamp': 'str',
        'difficulty': 'str',
        'proof_gamma': 'str',
        'proof_verification_hash': 'str',
        'proof_scalar': 'str',
        'previous_block_hash': 'str',
        'transactions_hash': 'str',
        'receipts_hash': 'str',
        'state_hash': 'str',
        'beneficiary_address': 'str',
        'fee_multiplier': 'int'
    }

    attribute_map = {
        'size': 'size',
        'signature': 'signature',
        'signer_public_key': 'signerPublicKey',
        'version': 'version',
        'network': 'network',
        'type': 'type',
        'height': 'height',
        'timestamp': 'timestamp',
        'difficulty': 'difficulty',
        'proof_gamma': 'proofGamma',
        'proof_verification_hash': 'proofVerificationHash',
        'proof_scalar': 'proofScalar',
        'previous_block_hash': 'previousBlockHash',
        'transactions_hash': 'transactionsHash',
        'receipts_hash': 'receiptsHash',
        'state_hash': 'stateHash',
        'beneficiary_address': 'beneficiaryAddress',
        'fee_multiplier': 'feeMultiplier'
    }

    def __init__(self, size=None, signature=None, signer_public_key=None, version=None, network=None, type=None, height=None, timestamp=None, difficulty=None, proof_gamma=None, proof_verification_hash=None, proof_scalar=None, previous_block_hash=None, transactions_hash=None, receipts_hash=None, state_hash=None, beneficiary_address=None, fee_multiplier=None, local_vars_configuration=None):  # noqa: E501
        """BlockDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._size = None
        self._signature = None
        self._signer_public_key = None
        self._version = None
        self._network = None
        self._type = None
        self._height = None
        self._timestamp = None
        self._difficulty = None
        self._proof_gamma = None
        self._proof_verification_hash = None
        self._proof_scalar = None
        self._previous_block_hash = None
        self._transactions_hash = None
        self._receipts_hash = None
        self._state_hash = None
        self._beneficiary_address = None
        self._fee_multiplier = None
        self.discriminator = None

        self.size = size
        self.signature = signature
        self.signer_public_key = signer_public_key
        self.version = version
        self.network = network
        self.type = type
        self.height = height
        self.timestamp = timestamp
        self.difficulty = difficulty
        self.proof_gamma = proof_gamma
        self.proof_verification_hash = proof_verification_hash
        self.proof_scalar = proof_scalar
        self.previous_block_hash = previous_block_hash
        self.transactions_hash = transactions_hash
        self.receipts_hash = receipts_hash
        self.state_hash = state_hash
        self.beneficiary_address = beneficiary_address
        self.fee_multiplier = fee_multiplier

    @property
    def size(self):
        """Gets the size of this BlockDTO.  # noqa: E501

        A number that allows uint 32 values.  # noqa: E501

        :return: The size of this BlockDTO.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this BlockDTO.

        A number that allows uint 32 values.  # noqa: E501

        :param size: The size of this BlockDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def signature(self):
        """Gets the signature of this BlockDTO.  # noqa: E501

        Entity's signature generated by the signer.  # noqa: E501

        :return: The signature of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this BlockDTO.

        Entity's signature generated by the signer.  # noqa: E501

        :param signature: The signature of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signature is None:  # noqa: E501
            raise ValueError("Invalid value for `signature`, must not be `None`")  # noqa: E501

        self._signature = signature

    @property
    def signer_public_key(self):
        """Gets the signer_public_key of this BlockDTO.  # noqa: E501

        Public key.  # noqa: E501

        :return: The signer_public_key of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._signer_public_key

    @signer_public_key.setter
    def signer_public_key(self, signer_public_key):
        """Sets the signer_public_key of this BlockDTO.

        Public key.  # noqa: E501

        :param signer_public_key: The signer_public_key of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signer_public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `signer_public_key`, must not be `None`")  # noqa: E501

        self._signer_public_key = signer_public_key

    @property
    def version(self):
        """Gets the version of this BlockDTO.  # noqa: E501

        Entity version.  # noqa: E501

        :return: The version of this BlockDTO.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BlockDTO.

        Entity version.  # noqa: E501

        :param version: The version of this BlockDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def network(self):
        """Gets the network of this BlockDTO.  # noqa: E501


        :return: The network of this BlockDTO.  # noqa: E501
        :rtype: NetworkTypeEnum
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this BlockDTO.


        :param network: The network of this BlockDTO.  # noqa: E501
        :type: NetworkTypeEnum
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def type(self):
        """Gets the type of this BlockDTO.  # noqa: E501


        :return: The type of this BlockDTO.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BlockDTO.


        :param type: The type of this BlockDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def height(self):
        """Gets the height of this BlockDTO.  # noqa: E501

        Height of the blockchain.  # noqa: E501

        :return: The height of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this BlockDTO.

        Height of the blockchain.  # noqa: E501

        :param height: The height of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and height is None:  # noqa: E501
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def timestamp(self):
        """Gets the timestamp of this BlockDTO.  # noqa: E501

        Number of seconds elapsed since the creation of the nemesis block.  # noqa: E501

        :return: The timestamp of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this BlockDTO.

        Number of seconds elapsed since the creation of the nemesis block.  # noqa: E501

        :param timestamp: The timestamp of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def difficulty(self):
        """Gets the difficulty of this BlockDTO.  # noqa: E501

        Determines how hard is to harvest a new block, based on previous blocks.  # noqa: E501

        :return: The difficulty of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._difficulty

    @difficulty.setter
    def difficulty(self, difficulty):
        """Sets the difficulty of this BlockDTO.

        Determines how hard is to harvest a new block, based on previous blocks.  # noqa: E501

        :param difficulty: The difficulty of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and difficulty is None:  # noqa: E501
            raise ValueError("Invalid value for `difficulty`, must not be `None`")  # noqa: E501

        self._difficulty = difficulty

    @property
    def proof_gamma(self):
        """Gets the proof_gamma of this BlockDTO.  # noqa: E501

        32-bytes VRF proof gamma.  # noqa: E501

        :return: The proof_gamma of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._proof_gamma

    @proof_gamma.setter
    def proof_gamma(self, proof_gamma):
        """Sets the proof_gamma of this BlockDTO.

        32-bytes VRF proof gamma.  # noqa: E501

        :param proof_gamma: The proof_gamma of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and proof_gamma is None:  # noqa: E501
            raise ValueError("Invalid value for `proof_gamma`, must not be `None`")  # noqa: E501

        self._proof_gamma = proof_gamma

    @property
    def proof_verification_hash(self):
        """Gets the proof_verification_hash of this BlockDTO.  # noqa: E501

        16-bytes VRF proof verification hash.  # noqa: E501

        :return: The proof_verification_hash of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._proof_verification_hash

    @proof_verification_hash.setter
    def proof_verification_hash(self, proof_verification_hash):
        """Sets the proof_verification_hash of this BlockDTO.

        16-bytes VRF proof verification hash.  # noqa: E501

        :param proof_verification_hash: The proof_verification_hash of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and proof_verification_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `proof_verification_hash`, must not be `None`")  # noqa: E501

        self._proof_verification_hash = proof_verification_hash

    @property
    def proof_scalar(self):
        """Gets the proof_scalar of this BlockDTO.  # noqa: E501

        32-bytes VRF proof scalar.  # noqa: E501

        :return: The proof_scalar of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._proof_scalar

    @proof_scalar.setter
    def proof_scalar(self, proof_scalar):
        """Sets the proof_scalar of this BlockDTO.

        32-bytes VRF proof scalar.  # noqa: E501

        :param proof_scalar: The proof_scalar of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and proof_scalar is None:  # noqa: E501
            raise ValueError("Invalid value for `proof_scalar`, must not be `None`")  # noqa: E501

        self._proof_scalar = proof_scalar

    @property
    def previous_block_hash(self):
        """Gets the previous_block_hash of this BlockDTO.  # noqa: E501


        :return: The previous_block_hash of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._previous_block_hash

    @previous_block_hash.setter
    def previous_block_hash(self, previous_block_hash):
        """Sets the previous_block_hash of this BlockDTO.


        :param previous_block_hash: The previous_block_hash of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and previous_block_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `previous_block_hash`, must not be `None`")  # noqa: E501

        self._previous_block_hash = previous_block_hash

    @property
    def transactions_hash(self):
        """Gets the transactions_hash of this BlockDTO.  # noqa: E501


        :return: The transactions_hash of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._transactions_hash

    @transactions_hash.setter
    def transactions_hash(self, transactions_hash):
        """Sets the transactions_hash of this BlockDTO.


        :param transactions_hash: The transactions_hash of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and transactions_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `transactions_hash`, must not be `None`")  # noqa: E501

        self._transactions_hash = transactions_hash

    @property
    def receipts_hash(self):
        """Gets the receipts_hash of this BlockDTO.  # noqa: E501


        :return: The receipts_hash of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._receipts_hash

    @receipts_hash.setter
    def receipts_hash(self, receipts_hash):
        """Sets the receipts_hash of this BlockDTO.


        :param receipts_hash: The receipts_hash of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and receipts_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `receipts_hash`, must not be `None`")  # noqa: E501

        self._receipts_hash = receipts_hash

    @property
    def state_hash(self):
        """Gets the state_hash of this BlockDTO.  # noqa: E501


        :return: The state_hash of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._state_hash

    @state_hash.setter
    def state_hash(self, state_hash):
        """Sets the state_hash of this BlockDTO.


        :param state_hash: The state_hash of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and state_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `state_hash`, must not be `None`")  # noqa: E501

        self._state_hash = state_hash

    @property
    def beneficiary_address(self):
        """Gets the beneficiary_address of this BlockDTO.  # noqa: E501

        Address expressed in hexadecimal base.  # noqa: E501

        :return: The beneficiary_address of this BlockDTO.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_address

    @beneficiary_address.setter
    def beneficiary_address(self, beneficiary_address):
        """Sets the beneficiary_address of this BlockDTO.

        Address expressed in hexadecimal base.  # noqa: E501

        :param beneficiary_address: The beneficiary_address of this BlockDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and beneficiary_address is None:  # noqa: E501
            raise ValueError("Invalid value for `beneficiary_address`, must not be `None`")  # noqa: E501

        self._beneficiary_address = beneficiary_address

    @property
    def fee_multiplier(self):
        """Gets the fee_multiplier of this BlockDTO.  # noqa: E501

        Fee multiplier applied to transactions contained in block.  # noqa: E501

        :return: The fee_multiplier of this BlockDTO.  # noqa: E501
        :rtype: int
        """
        return self._fee_multiplier

    @fee_multiplier.setter
    def fee_multiplier(self, fee_multiplier):
        """Sets the fee_multiplier of this BlockDTO.

        Fee multiplier applied to transactions contained in block.  # noqa: E501

        :param fee_multiplier: The fee_multiplier of this BlockDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and fee_multiplier is None:  # noqa: E501
            raise ValueError("Invalid value for `fee_multiplier`, must not be `None`")  # noqa: E501

        self._fee_multiplier = fee_multiplier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BlockDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class ChainPropertiesDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enable_verifiable_state': 'bool',
        'enable_verifiable_receipts': 'bool',
        'currency_mosaic_id': 'str',
        'harvesting_mosaic_id': 'str',
        'block_generation_target_time': 'str',
        'block_time_smoothing_factor': 'str',
        'block_finalization_interval': 'str',
        'importance_grouping': 'str',
        'importance_activity_percentage': 'str',
        'max_rollback_blocks': 'str',
        'max_difficulty_blocks': 'str',
        'default_dynamic_fee_multiplier': 'str',
        'max_transaction_lifetime': 'str',
        'max_block_future_time': 'str',
        'initial_currency_atomic_units': 'str',
        'max_mosaic_atomic_units': 'str',
        'total_chain_importance': 'str',
        'min_harvester_balance': 'str',
        'max_harvester_balance': 'str',
        'min_voter_balance': 'str',
        'max_voting_keys_per_account': 'str',
        'min_voting_key_lifetime': 'str',
        'max_voting_key_lifetime': 'str',
        'harvest_beneficiary_percentage': 'str',
        'harvest_network_percentage': 'str',
        'harvest_network_fee_sink_address': 'str',
        'block_prune_interval': 'str',
        'max_transactions_per_block': 'str'
    }

    attribute_map = {
        'enable_verifiable_state': 'enableVerifiableState',
        'enable_verifiable_receipts': 'enableVerifiableReceipts',
        'currency_mosaic_id': 'currencyMosaicId',
        'harvesting_mosaic_id': 'harvestingMosaicId',
        'block_generation_target_time': 'blockGenerationTargetTime',
        'block_time_smoothing_factor': 'blockTimeSmoothingFactor',
        'block_finalization_interval': 'blockFinalizationInterval',
        'importance_grouping': 'importanceGrouping',
        'importance_activity_percentage': 'importanceActivityPercentage',
        'max_rollback_blocks': 'maxRollbackBlocks',
        'max_difficulty_blocks': 'maxDifficultyBlocks',
        'default_dynamic_fee_multiplier': 'defaultDynamicFeeMultiplier',
        'max_transaction_lifetime': 'maxTransactionLifetime',
        'max_block_future_time': 'maxBlockFutureTime',
        'initial_currency_atomic_units': 'initialCurrencyAtomicUnits',
        'max_mosaic_atomic_units': 'maxMosaicAtomicUnits',
        'total_chain_importance': 'totalChainImportance',
        'min_harvester_balance': 'minHarvesterBalance',
        'max_harvester_balance': 'maxHarvesterBalance',
        'min_voter_balance': 'minVoterBalance',
        'max_voting_keys_per_account': 'maxVotingKeysPerAccount',
        'min_voting_key_lifetime': 'minVotingKeyLifetime',
        'max_voting_key_lifetime': 'maxVotingKeyLifetime',
        'harvest_beneficiary_percentage': 'harvestBeneficiaryPercentage',
        'harvest_network_percentage': 'harvestNetworkPercentage',
        'harvest_network_fee_sink_address': 'harvestNetworkFeeSinkAddress',
        'block_prune_interval': 'blockPruneInterval',
        'max_transactions_per_block': 'maxTransactionsPerBlock'
    }

    def __init__(self, enable_verifiable_state=None, enable_verifiable_receipts=None, currency_mosaic_id=None, harvesting_mosaic_id=None, block_generation_target_time=None, block_time_smoothing_factor=None, block_finalization_interval=None, importance_grouping=None, importance_activity_percentage=None, max_rollback_blocks=None, max_difficulty_blocks=None, default_dynamic_fee_multiplier=None, max_transaction_lifetime=None, max_block_future_time=None, initial_currency_atomic_units=None, max_mosaic_atomic_units=None, total_chain_importance=None, min_harvester_balance=None, max_harvester_balance=None, min_voter_balance=None, max_voting_keys_per_account=None, min_voting_key_lifetime=None, max_voting_key_lifetime=None, harvest_beneficiary_percentage=None, harvest_network_percentage=None, harvest_network_fee_sink_address=None, block_prune_interval=None, max_transactions_per_block=None, local_vars_configuration=None):  # noqa: E501
        """ChainPropertiesDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enable_verifiable_state = None
        self._enable_verifiable_receipts = None
        self._currency_mosaic_id = None
        self._harvesting_mosaic_id = None
        self._block_generation_target_time = None
        self._block_time_smoothing_factor = None
        self._block_finalization_interval = None
        self._importance_grouping = None
        self._importance_activity_percentage = None
        self._max_rollback_blocks = None
        self._max_difficulty_blocks = None
        self._default_dynamic_fee_multiplier = None
        self._max_transaction_lifetime = None
        self._max_block_future_time = None
        self._initial_currency_atomic_units = None
        self._max_mosaic_atomic_units = None
        self._total_chain_importance = None
        self._min_harvester_balance = None
        self._max_harvester_balance = None
        self._min_voter_balance = None
        self._max_voting_keys_per_account = None
        self._min_voting_key_lifetime = None
        self._max_voting_key_lifetime = None
        self._harvest_beneficiary_percentage = None
        self._harvest_network_percentage = None
        self._harvest_network_fee_sink_address = None
        self._block_prune_interval = None
        self._max_transactions_per_block = None
        self.discriminator = None

        if enable_verifiable_state is not None:
            self.enable_verifiable_state = enable_verifiable_state
        if enable_verifiable_receipts is not None:
            self.enable_verifiable_receipts = enable_verifiable_receipts
        if currency_mosaic_id is not None:
            self.currency_mosaic_id = currency_mosaic_id
        if harvesting_mosaic_id is not None:
            self.harvesting_mosaic_id = harvesting_mosaic_id
        if block_generation_target_time is not None:
            self.block_generation_target_time = block_generation_target_time
        if block_time_smoothing_factor is not None:
            self.block_time_smoothing_factor = block_time_smoothing_factor
        if block_finalization_interval is not None:
            self.block_finalization_interval = block_finalization_interval
        if importance_grouping is not None:
            self.importance_grouping = importance_grouping
        if importance_activity_percentage is not None:
            self.importance_activity_percentage = importance_activity_percentage
        if max_rollback_blocks is not None:
            self.max_rollback_blocks = max_rollback_blocks
        if max_difficulty_blocks is not None:
            self.max_difficulty_blocks = max_difficulty_blocks
        if default_dynamic_fee_multiplier is not None:
            self.default_dynamic_fee_multiplier = default_dynamic_fee_multiplier
        if max_transaction_lifetime is not None:
            self.max_transaction_lifetime = max_transaction_lifetime
        if max_block_future_time is not None:
            self.max_block_future_time = max_block_future_time
        if initial_currency_atomic_units is not None:
            self.initial_currency_atomic_units = initial_currency_atomic_units
        if max_mosaic_atomic_units is not None:
            self.max_mosaic_atomic_units = max_mosaic_atomic_units
        if total_chain_importance is not None:
            self.total_chain_importance = total_chain_importance
        if min_harvester_balance is not None:
            self.min_harvester_balance = min_harvester_balance
        if max_harvester_balance is not None:
            self.max_harvester_balance = max_harvester_balance
        if min_voter_balance is not None:
            self.min_voter_balance = min_voter_balance
        if max_voting_keys_per_account is not None:
            self.max_voting_keys_per_account = max_voting_keys_per_account
        if min_voting_key_lifetime is not None:
            self.min_voting_key_lifetime = min_voting_key_lifetime
        if max_voting_key_lifetime is not None:
            self.max_voting_key_lifetime = max_voting_key_lifetime
        if harvest_beneficiary_percentage is not None:
            self.harvest_beneficiary_percentage = harvest_beneficiary_percentage
        if harvest_network_percentage is not None:
            self.harvest_network_percentage = harvest_network_percentage
        if harvest_network_fee_sink_address is not None:
            self.harvest_network_fee_sink_address = harvest_network_fee_sink_address
        if block_prune_interval is not None:
            self.block_prune_interval = block_prune_interval
        if max_transactions_per_block is not None:
            self.max_transactions_per_block = max_transactions_per_block

    @property
    def enable_verifiable_state(self):
        """Gets the enable_verifiable_state of this ChainPropertiesDTO.  # noqa: E501

        Set to true if block chain should calculate state hashes so that state is fully verifiable at each block.  # noqa: E501

        :return: The enable_verifiable_state of this ChainPropertiesDTO.  # noqa: E501
        :rtype: bool
        """
        return self._enable_verifiable_state

    @enable_verifiable_state.setter
    def enable_verifiable_state(self, enable_verifiable_state):
        """Sets the enable_verifiable_state of this ChainPropertiesDTO.

        Set to true if block chain should calculate state hashes so that state is fully verifiable at each block.  # noqa: E501

        :param enable_verifiable_state: The enable_verifiable_state of this ChainPropertiesDTO.  # noqa: E501
        :type: bool
        """

        self._enable_verifiable_state = enable_verifiable_state

    @property
    def enable_verifiable_receipts(self):
        """Gets the enable_verifiable_receipts of this ChainPropertiesDTO.  # noqa: E501

        Set to true if block chain should calculate receipts so that state changes are fully verifiable at each block.  # noqa: E501

        :return: The enable_verifiable_receipts of this ChainPropertiesDTO.  # noqa: E501
        :rtype: bool
        """
        return self._enable_verifiable_receipts

    @enable_verifiable_receipts.setter
    def enable_verifiable_receipts(self, enable_verifiable_receipts):
        """Sets the enable_verifiable_receipts of this ChainPropertiesDTO.

        Set to true if block chain should calculate receipts so that state changes are fully verifiable at each block.  # noqa: E501

        :param enable_verifiable_receipts: The enable_verifiable_receipts of this ChainPropertiesDTO.  # noqa: E501
        :type: bool
        """

        self._enable_verifiable_receipts = enable_verifiable_receipts

    @property
    def currency_mosaic_id(self):
        """Gets the currency_mosaic_id of this ChainPropertiesDTO.  # noqa: E501

        Mosaic id used as primary chain currency.  # noqa: E501

        :return: The currency_mosaic_id of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._currency_mosaic_id

    @currency_mosaic_id.setter
    def currency_mosaic_id(self, currency_mosaic_id):
        """Sets the currency_mosaic_id of this ChainPropertiesDTO.

        Mosaic id used as primary chain currency.  # noqa: E501

        :param currency_mosaic_id: The currency_mosaic_id of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._currency_mosaic_id = currency_mosaic_id

    @property
    def harvesting_mosaic_id(self):
        """Gets the harvesting_mosaic_id of this ChainPropertiesDTO.  # noqa: E501

        Mosaic id used to provide harvesting ability.  # noqa: E501

        :return: The harvesting_mosaic_id of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._harvesting_mosaic_id

    @harvesting_mosaic_id.setter
    def harvesting_mosaic_id(self, harvesting_mosaic_id):
        """Sets the harvesting_mosaic_id of this ChainPropertiesDTO.

        Mosaic id used to provide harvesting ability.  # noqa: E501

        :param harvesting_mosaic_id: The harvesting_mosaic_id of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._harvesting_mosaic_id = harvesting_mosaic_id

    @property
    def block_generation_target_time(self):
        """Gets the block_generation_target_time of this ChainPropertiesDTO.  # noqa: E501

        Targeted time between blocks.  # noqa: E501

        :return: The block_generation_target_time of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._block_generation_target_time

    @block_generation_target_time.setter
    def block_generation_target_time(self, block_generation_target_time):
        """Sets the block_generation_target_time of this ChainPropertiesDTO.

        Targeted time between blocks.  # noqa: E501

        :param block_generation_target_time: The block_generation_target_time of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._block_generation_target_time = block_generation_target_time

    @property
    def block_time_smoothing_factor(self):
        """Gets the block_time_smoothing_factor of this ChainPropertiesDTO.  # noqa: E501

        A higher value makes the network more biased.  # noqa: E501

        :return: The block_time_smoothing_factor of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._block_time_smoothing_factor

    @block_time_smoothing_factor.setter
    def block_time_smoothing_factor(self, block_time_smoothing_factor):
        """Sets the block_time_smoothing_factor of this ChainPropertiesDTO.

        A higher value makes the network more biased.  # noqa: E501

        :param block_time_smoothing_factor: The block_time_smoothing_factor of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._block_time_smoothing_factor = block_time_smoothing_factor

    @property
    def block_finalization_interval(self):
        """Gets the block_finalization_interval of this ChainPropertiesDTO.  # noqa: E501

        Number of blocks between successive finalization attempts.  # noqa: E501

        :return: The block_finalization_interval of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._block_finalization_interval

    @block_finalization_interval.setter
    def block_finalization_interval(self, block_finalization_interval):
        """Sets the block_finalization_interval of this ChainPropertiesDTO.

        Number of blocks between successive finalization attempts.  # noqa: E501

        :param block_finalization_interval: The block_finalization_interval of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._block_finalization_interval = block_finalization_interval

    @property
    def importance_grouping(self):
        """Gets the importance_grouping of this ChainPropertiesDTO.  # noqa: E501

        Number of blocks that should be treated as a group for importance purposes.  # noqa: E501

        :return: The importance_grouping of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._importance_grouping

    @importance_grouping.setter
    def importance_grouping(self, importance_grouping):
        """Sets the importance_grouping of this ChainPropertiesDTO.

        Number of blocks that should be treated as a group for importance purposes.  # noqa: E501

        :param importance_grouping: The importance_grouping of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._importance_grouping = importance_grouping

    @property
    def importance_activity_percentage(self):
        """Gets the importance_activity_percentage of this ChainPropertiesDTO.  # noqa: E501

        Percentage of importance resulting from fee generation and beneficiary usage.  # noqa: E501

        :return: The importance_activity_percentage of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._importance_activity_percentage

    @importance_activity_percentage.setter
    def importance_activity_percentage(self, importance_activity_percentage):
        """Sets the importance_activity_percentage of this ChainPropertiesDTO.

        Percentage of importance resulting from fee generation and beneficiary usage.  # noqa: E501

        :param importance_activity_percentage: The importance_activity_percentage of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._importance_activity_percentage = importance_activity_percentage

    @property
    def max_rollback_blocks(self):
        """Gets the max_rollback_blocks of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of blocks that can be rolled back.  # noqa: E501

        :return: The max_rollback_blocks of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_rollback_blocks

    @max_rollback_blocks.setter
    def max_rollback_blocks(self, max_rollback_blocks):
        """Sets the max_rollback_blocks of this ChainPropertiesDTO.

        Maximum number of blocks that can be rolled back.  # noqa: E501

        :param max_rollback_blocks: The max_rollback_blocks of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_rollback_blocks = max_rollback_blocks

    @property
    def max_difficulty_blocks(self):
        """Gets the max_difficulty_blocks of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of blocks to use in a difficulty calculation.  # noqa: E501

        :return: The max_difficulty_blocks of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_difficulty_blocks

    @max_difficulty_blocks.setter
    def max_difficulty_blocks(self, max_difficulty_blocks):
        """Sets the max_difficulty_blocks of this ChainPropertiesDTO.

        Maximum number of blocks to use in a difficulty calculation.  # noqa: E501

        :param max_difficulty_blocks: The max_difficulty_blocks of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_difficulty_blocks = max_difficulty_blocks

    @property
    def default_dynamic_fee_multiplier(self):
        """Gets the default_dynamic_fee_multiplier of this ChainPropertiesDTO.  # noqa: E501

        Default multiplier to use for dynamic fees.  # noqa: E501

        :return: The default_dynamic_fee_multiplier of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._default_dynamic_fee_multiplier

    @default_dynamic_fee_multiplier.setter
    def default_dynamic_fee_multiplier(self, default_dynamic_fee_multiplier):
        """Sets the default_dynamic_fee_multiplier of this ChainPropertiesDTO.

        Default multiplier to use for dynamic fees.  # noqa: E501

        :param default_dynamic_fee_multiplier: The default_dynamic_fee_multiplier of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._default_dynamic_fee_multiplier = default_dynamic_fee_multiplier

    @property
    def max_transaction_lifetime(self):
        """Gets the max_transaction_lifetime of this ChainPropertiesDTO.  # noqa: E501

        Maximum lifetime a transaction can have before it expires.  # noqa: E501

        :return: The max_transaction_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_transaction_lifetime

    @max_transaction_lifetime.setter
    def max_transaction_lifetime(self, max_transaction_lifetime):
        """Sets the max_transaction_lifetime of this ChainPropertiesDTO.

        Maximum lifetime a transaction can have before it expires.  # noqa: E501

        :param max_transaction_lifetime: The max_transaction_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_transaction_lifetime = max_transaction_lifetime

    @property
    def max_block_future_time(self):
        """Gets the max_block_future_time of this ChainPropertiesDTO.  # noqa: E501

        Maximum future time of a block that can be accepted.  # noqa: E501

        :return: The max_block_future_time of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_block_future_time

    @max_block_future_time.setter
    def max_block_future_time(self, max_block_future_time):
        """Sets the max_block_future_time of this ChainPropertiesDTO.

        Maximum future time of a block that can be accepted.  # noqa: E501

        :param max_block_future_time: The max_block_future_time of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_block_future_time = max_block_future_time

    @property
    def initial_currency_atomic_units(self):
        """Gets the initial_currency_atomic_units of this ChainPropertiesDTO.  # noqa: E501

        Initial currency atomic units available in the network.  # noqa: E501

        :return: The initial_currency_atomic_units of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._initial_currency_atomic_units

    @initial_currency_atomic_units.setter
    def initial_currency_atomic_units(self, initial_currency_atomic_units):
        """Sets the initial_currency_atomic_units of this ChainPropertiesDTO.

        Initial currency atomic units available in the network.  # noqa: E501

        :param initial_currency_atomic_units: The initial_currency_atomic_units of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._initial_currency_atomic_units = initial_currency_atomic_units

    @property
    def max_mosaic_atomic_units(self):
        """Gets the max_mosaic_atomic_units of this ChainPropertiesDTO.  # noqa: E501

        Maximum atomic units (total-supply * 10 ^ divisibility) of a mosaic allowed in the network.  # noqa: E501

        :return: The max_mosaic_atomic_units of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_mosaic_atomic_units

    @max_mosaic_atomic_units.setter
    def max_mosaic_atomic_units(self, max_mosaic_atomic_units):
        """Sets the max_mosaic_atomic_units of this ChainPropertiesDTO.

        Maximum atomic units (total-supply * 10 ^ divisibility) of a mosaic allowed in the network.  # noqa: E501

        :param max_mosaic_atomic_units: The max_mosaic_atomic_units of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_mosaic_atomic_units = max_mosaic_atomic_units

    @property
    def total_chain_importance(self):
        """Gets the total_chain_importance of this ChainPropertiesDTO.  # noqa: E501

        Total whole importance units available in the network.  # noqa: E501

        :return: The total_chain_importance of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._total_chain_importance

    @total_chain_importance.setter
    def total_chain_importance(self, total_chain_importance):
        """Sets the total_chain_importance of this ChainPropertiesDTO.

        Total whole importance units available in the network.  # noqa: E501

        :param total_chain_importance: The total_chain_importance of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._total_chain_importance = total_chain_importance

    @property
    def min_harvester_balance(self):
        """Gets the min_harvester_balance of this ChainPropertiesDTO.  # noqa: E501

        Minimum number of harvesting mosaic atomic units needed for an account to be eligible for harvesting.  # noqa: E501

        :return: The min_harvester_balance of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._min_harvester_balance

    @min_harvester_balance.setter
    def min_harvester_balance(self, min_harvester_balance):
        """Sets the min_harvester_balance of this ChainPropertiesDTO.

        Minimum number of harvesting mosaic atomic units needed for an account to be eligible for harvesting.  # noqa: E501

        :param min_harvester_balance: The min_harvester_balance of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._min_harvester_balance = min_harvester_balance

    @property
    def max_harvester_balance(self):
        """Gets the max_harvester_balance of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of harvesting mosaic atomic units needed for an account to be eligible for harvesting.  # noqa: E501

        :return: The max_harvester_balance of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_harvester_balance

    @max_harvester_balance.setter
    def max_harvester_balance(self, max_harvester_balance):
        """Sets the max_harvester_balance of this ChainPropertiesDTO.

        Maximum number of harvesting mosaic atomic units needed for an account to be eligible for harvesting.  # noqa: E501

        :param max_harvester_balance: The max_harvester_balance of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_harvester_balance = max_harvester_balance

    @property
    def min_voter_balance(self):
        """Gets the min_voter_balance of this ChainPropertiesDTO.  # noqa: E501

        Minimum number of harvesting mosaic atomic units needed for an account to be eligible for voting.  # noqa: E501

        :return: The min_voter_balance of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._min_voter_balance

    @min_voter_balance.setter
    def min_voter_balance(self, min_voter_balance):
        """Sets the min_voter_balance of this ChainPropertiesDTO.

        Minimum number of harvesting mosaic atomic units needed for an account to be eligible for voting.  # noqa: E501

        :param min_voter_balance: The min_voter_balance of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._min_voter_balance = min_voter_balance

    @property
    def max_voting_keys_per_account(self):
        """Gets the max_voting_keys_per_account of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of voting keys that can be registered at once per account.  # noqa: E501

        :return: The max_voting_keys_per_account of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_voting_keys_per_account

    @max_voting_keys_per_account.setter
    def max_voting_keys_per_account(self, max_voting_keys_per_account):
        """Sets the max_voting_keys_per_account of this ChainPropertiesDTO.

        Maximum number of voting keys that can be registered at once per account.  # noqa: E501

        :param max_voting_keys_per_account: The max_voting_keys_per_account of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_voting_keys_per_account = max_voting_keys_per_account

    @property
    def min_voting_key_lifetime(self):
        """Gets the min_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501

        Minimum number of finalization rounds for which voting key can be registered.  # noqa: E501

        :return: The min_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._min_voting_key_lifetime

    @min_voting_key_lifetime.setter
    def min_voting_key_lifetime(self, min_voting_key_lifetime):
        """Sets the min_voting_key_lifetime of this ChainPropertiesDTO.

        Minimum number of finalization rounds for which voting key can be registered.  # noqa: E501

        :param min_voting_key_lifetime: The min_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._min_voting_key_lifetime = min_voting_key_lifetime

    @property
    def max_voting_key_lifetime(self):
        """Gets the max_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of finalization rounds for which voting key can be registered.  # noqa: E501

        :return: The max_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_voting_key_lifetime

    @max_voting_key_lifetime.setter
    def max_voting_key_lifetime(self, max_voting_key_lifetime):
        """Sets the max_voting_key_lifetime of this ChainPropertiesDTO.

        Maximum number of finalization rounds for which voting key can be registered.  # noqa: E501

        :param max_voting_key_lifetime: The max_voting_key_lifetime of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_voting_key_lifetime = max_voting_key_lifetime

    @property
    def harvest_beneficiary_percentage(self):
        """Gets the harvest_beneficiary_percentage of this ChainPropertiesDTO.  # noqa: E501

        Percentage of the harvested fee that is collected by the beneficiary account.  # noqa: E501

        :return: The harvest_beneficiary_percentage of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._harvest_beneficiary_percentage

    @harvest_beneficiary_percentage.setter
    def harvest_beneficiary_percentage(self, harvest_beneficiary_percentage):
        """Sets the harvest_beneficiary_percentage of this ChainPropertiesDTO.

        Percentage of the harvested fee that is collected by the beneficiary account.  # noqa: E501

        :param harvest_beneficiary_percentage: The harvest_beneficiary_percentage of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._harvest_beneficiary_percentage = harvest_beneficiary_percentage

    @property
    def harvest_network_percentage(self):
        """Gets the harvest_network_percentage of this ChainPropertiesDTO.  # noqa: E501

        Percentage of the harvested fee that is collected by the network.  # noqa: E501

        :return: The harvest_network_percentage of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._harvest_network_percentage

    @harvest_network_percentage.setter
    def harvest_network_percentage(self, harvest_network_percentage):
        """Sets the harvest_network_percentage of this ChainPropertiesDTO.

        Percentage of the harvested fee that is collected by the network.  # noqa: E501

        :param harvest_network_percentage: The harvest_network_percentage of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._harvest_network_percentage = harvest_network_percentage

    @property
    def harvest_network_fee_sink_address(self):
        """Gets the harvest_network_fee_sink_address of this ChainPropertiesDTO.  # noqa: E501

        Address encoded using a 32-character set.  # noqa: E501

        :return: The harvest_network_fee_sink_address of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._harvest_network_fee_sink_address

    @harvest_network_fee_sink_address.setter
    def harvest_network_fee_sink_address(self, harvest_network_fee_sink_address):
        """Sets the harvest_network_fee_sink_address of this ChainPropertiesDTO.

        Address encoded using a 32-character set.  # noqa: E501

        :param harvest_network_fee_sink_address: The harvest_network_fee_sink_address of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._harvest_network_fee_sink_address = harvest_network_fee_sink_address

    @property
    def block_prune_interval(self):
        """Gets the block_prune_interval of this ChainPropertiesDTO.  # noqa: E501

        Number of blocks between cache pruning.  # noqa: E501

        :return: The block_prune_interval of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._block_prune_interval

    @block_prune_interval.setter
    def block_prune_interval(self, block_prune_interval):
        """Sets the block_prune_interval of this ChainPropertiesDTO.

        Number of blocks between cache pruning.  # noqa: E501

        :param block_prune_interval: The block_prune_interval of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._block_prune_interval = block_prune_interval

    @property
    def max_transactions_per_block(self):
        """Gets the max_transactions_per_block of this ChainPropertiesDTO.  # noqa: E501

        Maximum number of transactions per block.  # noqa: E501

        :return: The max_transactions_per_block of this ChainPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_transactions_per_block

    @max_transactions_per_block.setter
    def max_transactions_per_block(self, max_transactions_per_block):
        """Sets the max_transactions_per_block of this ChainPropertiesDTO.

        Maximum number of transactions per block.  # noqa: E501

        :param max_transactions_per_block: The max_transactions_per_block of this ChainPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_transactions_per_block = max_transactions_per_block

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChainPropertiesDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChainPropertiesDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class NamespaceNetworkPropertiesDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_name_size': 'str',
        'max_child_namespaces': 'str',
        'max_namespace_depth': 'str',
        'min_namespace_duration': 'str',
        'max_namespace_duration': 'str',
        'namespace_grace_period_duration': 'str',
        'reserved_root_namespace_names': 'str',
        'namespace_rental_fee_sink_address': 'str',
        'root_namespace_rental_fee_per_block': 'str',
        'child_namespace_rental_fee': 'str'
    }

    attribute_map = {
        'max_name_size': 'maxNameSize',
        'max_child_namespaces': 'maxChildNamespaces',
        'max_namespace_depth': 'maxNamespaceDepth',
        'min_namespace_duration': 'minNamespaceDuration',
        'max_namespace_duration': 'maxNamespaceDuration',
        'namespace_grace_period_duration': 'namespaceGracePeriodDuration',
        'reserved_root_namespace_names': 'reservedRootNamespaceNames',
        'namespace_rental_fee_sink_address': 'namespaceRentalFeeSinkAddress',
        'root_namespace_rental_fee_per_block': 'rootNamespaceRentalFeePerBlock',
        'child_namespace_rental_fee': 'childNamespaceRentalFee'
    }

    def __init__(self, max_name_size=None, max_child_namespaces=None, max_namespace_depth=None, min_namespace_duration=None, max_namespace_duration=None, namespace_grace_period_duration=None, reserved_root_namespace_names=None, namespace_rental_fee_sink_address=None, root_namespace_rental_fee_per_block=None, child_namespace_rental_fee=None, local_vars_configuration=None):  # noqa: E501
        """NamespaceNetworkPropertiesDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._max_name_size = None
        self._max_child_namespaces = None
        self._max_namespace_depth = None
        self._min_namespace_duration = None
        self._max_namespace_duration = None
        self._namespace_grace_period_duration = None
        self._reserved_root_namespace_names = None
        self._namespace_rental_fee_sink_address = None
        self._root_namespace_rental_fee_per_block = None
        self._child_namespace_rental_fee = None
        self.discriminator = None

        if max_name_size is not None:
            self.max_name_size = max_name_size
        if max_child_namespaces is not None:
            self.max_child_namespaces = max_child_namespaces
        if max_namespace_depth is not None:
            self.max_namespace_depth = max_namespace_depth
        if min_namespace_duration is not None:
            self.min_namespace_duration = min_namespace_duration
        if max_namespace_duration is not None:
            self.max_namespace_duration = max_namespace_duration
        if namespace_grace_period_duration is not None:
            self.namespace_grace_period_duration = namespace_grace_period_duration
        if reserved_root_namespace_names is not None:
            self.reserved_root_namespace_names = reserved_root_namespace_names
        if namespace_rental_fee_sink_address is not None:
            self.namespace_rental_fee_sink_address = namespace_rental_fee_sink_address
        if root_namespace_rental_fee_per_block is not None:
            self.root_namespace_rental_fee_per_block = root_namespace_rental_fee_per_block
        if child_namespace_rental_fee is not None:
            self.child_namespace_rental_fee = child_namespace_rental_fee

    @property
    def max_name_size(self):
        """Gets the max_name_size of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Maximum namespace name size.  # noqa: E501

        :return: The max_name_size of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_name_size

    @max_name_size.setter
    def max_name_size(self, max_name_size):
        """Sets the max_name_size of this NamespaceNetworkPropertiesDTO.

        Maximum namespace name size.  # noqa: E501

        :param max_name_size: The max_name_size of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_name_size = max_name_size

    @property
    def max_child_namespaces(self):
        """Gets the max_child_namespaces of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Maximum number of children for a root namespace.  # noqa: E501

        :return: The max_child_namespaces of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_child_namespaces

    @max_child_namespaces.setter
    def max_child_namespaces(self, max_child_namespaces):
        """Sets the max_child_namespaces of this NamespaceNetworkPropertiesDTO.

        Maximum number of children for a root namespace.  # noqa: E501

        :param max_child_namespaces: The max_child_namespaces of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_child_namespaces = max_child_namespaces

    @property
    def max_namespace_depth(self):
        """Gets the max_namespace_depth of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Maximum namespace depth.  # noqa: E501

        :return: The max_namespace_depth of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_namespace_depth

    @max_namespace_depth.setter
    def max_namespace_depth(self, max_namespace_depth):
        """Sets the max_namespace_depth of this NamespaceNetworkPropertiesDTO.

        Maximum namespace depth.  # noqa: E501

        :param max_namespace_depth: The max_namespace_depth of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_namespace_depth = max_namespace_depth

    @property
    def min_namespace_duration(self):
        """Gets the min_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Minimum namespace duration.  # noqa: E501

        :return: The min_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._min_namespace_duration

    @min_namespace_duration.setter
    def min_namespace_duration(self, min_namespace_duration):
        """Sets the min_namespace_duration of this NamespaceNetworkPropertiesDTO.

        Minimum namespace duration.  # noqa: E501

        :param min_namespace_duration: The min_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._min_namespace_duration = min_namespace_duration

    @property
    def max_namespace_duration(self):
        """Gets the max_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Maximum namespace duration.  # noqa: E501

        :return: The max_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._max_namespace_duration

    @max_namespace_duration.setter
    def max_namespace_duration(self, max_namespace_duration):
        """Sets the max_namespace_duration of this NamespaceNetworkPropertiesDTO.

        Maximum namespace duration.  # noqa: E501

        :param max_namespace_duration: The max_namespace_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._max_namespace_duration = max_namespace_duration

    @property
    def namespace_grace_period_duration(self):
        """Gets the namespace_grace_period_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Grace period during which time only the previous owner can renew an expired namespace.  # noqa: E501

        :return: The namespace_grace_period_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._namespace_grace_period_duration

    @namespace_grace_period_duration.setter
    def namespace_grace_period_duration(self, namespace_grace_period_duration):
        """Sets the namespace_grace_period_duration of this NamespaceNetworkPropertiesDTO.

        Grace period during which time only the previous owner can renew an expired namespace.  # noqa: E501

        :param namespace_grace_period_duration: The namespace_grace_period_duration of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._namespace_grace_period_duration = namespace_grace_period_duration

    @property
    def reserved_root_namespace_names(self):
        """Gets the reserved_root_namespace_names of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Reserved root namespaces that cannot be claimed.  # noqa: E501

        :return: The reserved_root_namespace_names of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._reserved_root_namespace_names

    @reserved_root_namespace_names.setter
    def reserved_root_namespace_names(self, reserved_root_namespace_names):
        """Sets the reserved_root_namespace_names of this NamespaceNetworkPropertiesDTO.

        Reserved root namespaces that cannot be claimed.  # noqa: E501

        :param reserved_root_namespace_names: The reserved_root_namespace_names of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._reserved_root_namespace_names = reserved_root_namespace_names

    @property
    def namespace_rental_fee_sink_address(self):
        """Gets the namespace_rental_fee_sink_address of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Address encoded using a 32-character set.  # noqa: E501

        :return: The namespace_rental_fee_sink_address of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._namespace_rental_fee_sink_address

    @namespace_rental_fee_sink_address.setter
    def namespace_rental_fee_sink_address(self, namespace_rental_fee_sink_address):
        """Sets the namespace_rental_fee_sink_address of this NamespaceNetworkPropertiesDTO.

        Address encoded using a 32-character set.  # noqa: E501

        :param namespace_rental_fee_sink_address: The namespace_rental_fee_sink_address of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._namespace_rental_fee_sink_address = namespace_rental_fee_sink_address

    @property
    def root_namespace_rental_fee_per_block(self):
        """Gets the root_namespace_rental_fee_per_block of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Root namespace rental fee per block.  # noqa: E501

        :return: The root_namespace_rental_fee_per_block of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._root_namespace_rental_fee_per_block

    @root_namespace_rental_fee_per_block.setter
    def root_namespace_rental_fee_per_block(self, root_namespace_rental_fee_per_block):
        """Sets the root_namespace_rental_fee_per_block of this NamespaceNetworkPropertiesDTO.

        Root namespace rental fee per block.  # noqa: E501

        :param root_namespace_rental_fee_per_block: The root_namespace_rental_fee_per_block of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._root_namespace_rental_fee_per_block = root_namespace_rental_fee_per_block

    @property
    def child_namespace_rental_fee(self):
        """Gets the child_namespace_rental_fee of this NamespaceNetworkPropertiesDTO.  # noqa: E501

        Child namespace rental fee.  # noqa: E501

        :return: The child_namespace_rental_fee of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :rtype: str
        """
        return self._child_namespace_rental_fee

    @child_namespace_rental_fee.setter
    def child_namespace_rental_fee(self, child_namespace_rental_fee):
        """Sets the child_namespace_rental_fee of this NamespaceNetworkPropertiesDTO.

        Child namespace rental fee.  # noqa: E501

        :param child_namespace_rental_fee: The child_namespace_rental_fee of this NamespaceNetworkPropertiesDTO.  # noqa: E501
        :type: str
        """

        self._child_namespace_rental_fee = child_namespace_rental_fee

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NamespaceNetworkPropertiesDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NamespaceNetworkPropertiesDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class BalanceChangeReceiptDTOAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'mosaic_id': 'str',
        'amount': 'str',
        'target_address': 'str'
    }

    attribute_map = {
        'mosaic_id': 'mosaicId',
        'amount': 'amount',
        'target_address': 'targetAddress'
    }

    def __init__(self, mosaic_id=None, amount=None, target_address=None, local_vars_configuration=None):  # noqa: E501
        """BalanceChangeReceiptDTOAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._mosaic_id = None
        self._amount = None
        self._target_address = None
        self.discriminator = None

        self.mosaic_id = mosaic_id
        self.amount = amount
        self.target_address = target_address

    @property
    def mosaic_id(self):
        """Gets the mosaic_id of this BalanceChangeReceiptDTOAllOf.  # noqa: E501

        Mosaic identifier.  # noqa: E501

        :return: The mosaic_id of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :rtype: str
        """
        return self._mosaic_id

    @mosaic_id.setter
    def mosaic_id(self, mosaic_id):
        """Sets the mosaic_id of this BalanceChangeReceiptDTOAllOf.

        Mosaic identifier.  # noqa: E501

        :param mosaic_id: The mosaic_id of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and mosaic_id is None:  # noqa: E501
            raise ValueError("Invalid value for `mosaic_id`, must not be `None`")  # noqa: E501

        self._mosaic_id = mosaic_id

    @property
    def amount(self):
        """Gets the amount of this BalanceChangeReceiptDTOAllOf.  # noqa: E501

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :return: The amount of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BalanceChangeReceiptDTOAllOf.

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :param amount: The amount of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def target_address(self):
        """Gets the target_address of this BalanceChangeReceiptDTOAllOf.  # noqa: E501

        Address expressed in hexadecimal base.  # noqa: E501

        :return: The target_address of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :rtype: str
        """
        return self._target_address

    @target_address.setter
    def target_address(self, target_address):
        """Sets the target_address of this BalanceChangeReceiptDTOAllOf.

        Address expressed in hexadecimal base.  # noqa: E501

        :param target_address: The target_address of this BalanceChangeReceiptDTOAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_address is None:  # noqa: E501
            raise ValueError("Invalid value for `target_address`, must not be `None`")  # noqa: E501

        self._target_address = target_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BalanceChangeReceiptDTOAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BalanceChangeReceiptDTOAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class BlockMetaDTO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hash': 'str',
        'total_fee': 'str',
        'generation_hash': 'str',
        'state_hash_sub_cache_merkle_roots': 'list[str]',
        'total_transactions_count': 'int',
        'transactions_count': 'int',
        'statements_count': 'int'
    }

    attribute_map = {
        'hash': 'hash',
        'total_fee': 'totalFee',
        'generation_hash': 'generationHash',
        'state_hash_sub_cache_merkle_roots': 'stateHashSubCacheMerkleRoots',
        'total_transactions_count': 'totalTransactionsCount',
        'transactions_count': 'transactionsCount',
        'statements_count': 'statementsCount'
    }

    def __init__(self, hash=None, total_fee=None, generation_hash=None, state_hash_sub_cache_merkle_roots=None, total_transactions_count=None, transactions_count=None, statements_count=None, local_vars_configuration=None):  # noqa: E501
        """BlockMetaDTO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._hash = None
        self._total_fee = None
        self._generation_hash = None
        self._state_hash_sub_cache_merkle_roots = None
        self._total_transactions_count = None
        self._transactions_count = None
        self._statements_count = None
        self.discriminator = None

        self.hash = hash
        self.total_fee = total_fee
        self.generation_hash = generation_hash
        self.state_hash_sub_cache_merkle_roots = state_hash_sub_cache_merkle_roots
        self.total_transactions_count = total_transactions_count
        self.transactions_count = transactions_count
        self.statements_count = statements_count

    @property
    def hash(self):
        """Gets the hash of this BlockMetaDTO.  # noqa: E501


        :return: The hash of this BlockMetaDTO.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this BlockMetaDTO.


        :param hash: The hash of this BlockMetaDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and hash is None:  # noqa: E501
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def total_fee(self):
        """Gets the total_fee of this BlockMetaDTO.  # noqa: E501

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :return: The total_fee of this BlockMetaDTO.  # noqa: E501
        :rtype: str
        """
        return self._total_fee

    @total_fee.setter
    def total_fee(self, total_fee):
        """Sets the total_fee of this BlockMetaDTO.

        Absolute amount. An amount of 123456789 (absolute) for a mosaic with divisibility 6 means 123.456789 (relative).  # noqa: E501

        :param total_fee: The total_fee of this BlockMetaDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and total_fee is None:  # noqa: E501
            raise ValueError("Invalid value for `total_fee`, must not be `None`")  # noqa: E501

        self._total_fee = total_fee

    @property
    def generation_hash(self):
        """Gets the generation_hash of this BlockMetaDTO.  # noqa: E501


        :return: The generation_hash of this BlockMetaDTO.  # noqa: E501
        :rtype: str
        """
        return self._generation_hash

    @generation_hash.setter
    def generation_hash(self, generation_hash):
        """Sets the generation_hash of this BlockMetaDTO.


        :param generation_hash: The generation_hash of this BlockMetaDTO.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and generation_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `generation_hash`, must not be `None`")  # noqa: E501

        self._generation_hash = generation_hash

    @property
    def state_hash_sub_cache_merkle_roots(self):
        """Gets the state_hash_sub_cache_merkle_roots of this BlockMetaDTO.  # noqa: E501


        :return: The state_hash_sub_cache_merkle_roots of this BlockMetaDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._state_hash_sub_cache_merkle_roots

    @state_hash_sub_cache_merkle_roots.setter
    def state_hash_sub_cache_merkle_roots(self, state_hash_sub_cache_merkle_roots):
        """Sets the state_hash_sub_cache_merkle_roots of this BlockMetaDTO.


        :param state_hash_sub_cache_merkle_roots: The state_hash_sub_cache_merkle_roots of this BlockMetaDTO.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and state_hash_sub_cache_merkle_roots is None:  # noqa: E501
            raise ValueError("Invalid value for `state_hash_sub_cache_merkle_roots`, must not be `None`")  # noqa: E501

        self._state_hash_sub_cache_merkle_roots = state_hash_sub_cache_merkle_roots

    @property
    def total_transactions_count(self):
        """Gets the total_transactions_count of this BlockMetaDTO.  # noqa: E501

        Total number of [transactions](https://docs.symbolplatform.com/concepts/transaction.html) confirmed in this block, including *embedded* transactions (i.e. transactions contained within aggregate transactions).   # noqa: E501

        :return: The total_transactions_count of this BlockMetaDTO.  # noqa: E501
        :rtype: int
        """
        return self._total_transactions_count

    @total_transactions_count.setter
    def total_transactions_count(self, total_transactions_count):
        """Sets the total_transactions_count of this BlockMetaDTO.

        Total number of [transactions](https://docs.symbolplatform.com/concepts/transaction.html) confirmed in this block, including *embedded* transactions (i.e. transactions contained within aggregate transactions).   # noqa: E501

        :param total_transactions_count: The total_transactions_count of this BlockMetaDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_transactions_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_transactions_count`, must not be `None`")  # noqa: E501

        self._total_transactions_count = total_transactions_count

    @property
    def transactions_count(self):
        """Gets the transactions_count of this BlockMetaDTO.  # noqa: E501

        Number of [transactions](https://docs.symbolplatform.com/concepts/transaction.html) confirmed in this block. This does not count *embedded* transactions (i.e. transactions contained within aggregate transactions).   # noqa: E501

        :return: The transactions_count of this BlockMetaDTO.  # noqa: E501
        :rtype: int
        """
        return self._transactions_count

    @transactions_count.setter
    def transactions_count(self, transactions_count):
        """Sets the transactions_count of this BlockMetaDTO.

        Number of [transactions](https://docs.symbolplatform.com/concepts/transaction.html) confirmed in this block. This does not count *embedded* transactions (i.e. transactions contained within aggregate transactions).   # noqa: E501

        :param transactions_count: The transactions_count of this BlockMetaDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and transactions_count is None:  # noqa: E501
            raise ValueError("Invalid value for `transactions_count`, must not be `None`")  # noqa: E501

        self._transactions_count = transactions_count

    @property
    def statements_count(self):
        """Gets the statements_count of this BlockMetaDTO.  # noqa: E501

        Number of statements (of any kind) present in this block. Bear in mind that some of them (like [resolution statements](https://docs.symbolplatform.com/concepts/receipt.html#resolution-statement)) are triggered by transactions present in the block, but in general, [transaction statements](https://docs.symbolplatform.com/concepts/receipt.html#transaction-statement) are not.   # noqa: E501

        :return: The statements_count of this BlockMetaDTO.  # noqa: E501
        :rtype: int
        """
        return self._statements_count

    @statements_count.setter
    def statements_count(self, statements_count):
        """Sets the statements_count of this BlockMetaDTO.

        Number of statements (of any kind) present in this block. Bear in mind that some of them (like [resolution statements](https://docs.symbolplatform.com/concepts/receipt.html#resolution-statement)) are triggered by transactions present in the block, but in general, [transaction statements](https://docs.symbolplatform.com/concepts/receipt.html#transaction-statement) are not.   # noqa: E501

        :param statements_count: The statements_count of this BlockMetaDTO.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and statements_count is None:  # noqa: E501
            raise ValueError("Invalid value for `statements_count`, must not be `None`")  # noqa: E501

        self._statements_count = statements_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockMetaDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BlockMetaDTO):
            return True

        return self.to_dict() != other.to_dict()
